==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/WebGridRowTemplateContextDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebRowTypeDescriptionMetadata } from "./WebRowTypeDescriptionMetadata";
import { WebGridRowTemplateContextDescription } from "./WebGridRowTemplateContextDescription";
/**
 * @hidden
 */
export let WebGridRowTemplateContextDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebGridRowTemplateContextDescriptionMetadata extends Base {
        static b(a) {
            if (WebGridRowTemplateContextDescriptionMetadata.a == null) {
                WebGridRowTemplateContextDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebGridRowTemplateContextDescriptionMetadata.c(WebGridRowTemplateContextDescriptionMetadata.a);
            }
            if (a.j(WebGridRowTemplateContextDescriptionMetadata.a)) {
                return;
            }
            a.y(WebGridRowTemplateContextDescriptionMetadata.a);
            WebRowTypeDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:GridRowTemplateContext");
            a.item("__packageNameWC", "String:grids");
            a.item("__isPlainObject", "Boolean");
            a.item("Implicit", "ExportedType:WebRowType");
        }
        static d(a) {
            WebGridRowTemplateContextDescriptionMetadata.b(a);
            a.aa("WebGridRowTemplateContext", () => new WebGridRowTemplateContextDescription());
            a.z("WebGridRowTemplateContext", WebGridRowTemplateContextDescriptionMetadata.a);
        }
    }
    WebGridRowTemplateContextDescriptionMetadata.$t = /*@__PURE__*/ markType(WebGridRowTemplateContextDescriptionMetadata, 'WebGridRowTemplateContextDescriptionMetadata');
    WebGridRowTemplateContextDescriptionMetadata.a = null;
    return WebGridRowTemplateContextDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebGridRowTemplateContextDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebRowTypeDescriptionMetadata } from "./WebRowTypeDescriptionMetadata";
import { WebGridRowTemplateContextDescription } from "./WebGridRowTemplateContextDescription";
/**
 * @hidden
 */
export let WebGridRowTemplateContextDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebGridRowTemplateContextDescriptionMetadata extends Base {
        static b(a) {
            if (WebGridRowTemplateContextDescriptionMetadata.a == null) {
                WebGridRowTemplateContextDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebGridRowTemplateContextDescriptionMetadata.c(WebGridRowTemplateContextDescriptionMetadata.a);
            }
            if (a.k(WebGridRowTemplateContextDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebGridRowTemplateContextDescriptionMetadata.a);
            WebRowTypeDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:GridRowTemplateContext");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__isPlainObject", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("Implicit", "ExportedType:WebRowType");
        }
        static d(a) {
            WebGridRowTemplateContextDescriptionMetadata.b(a);
            a.ac("WebGridRowTemplateContext", () => new WebGridRowTemplateContextDescription());
            a.ab("WebGridRowTemplateContext", WebGridRowTemplateContextDescriptionMetadata.a);
        }
    }
    WebGridRowTemplateContextDescriptionMetadata.$t = /*@__PURE__*/ markType(WebGridRowTemplateContextDescriptionMetadata, 'WebGridRowTemplateContextDescriptionMetadata');
    WebGridRowTemplateContextDescriptionMetadata.a = null;
    return WebGridRowTemplateContextDescriptionMetadata;
})();
